<?php
namespace Teknisa\FIS\Controllers;

use Teknisa\FIS\Services\Fis57000FichaConteudoImportacaoService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;


class Fis57000FichaConteudoImportacaoController extends \Teknisa\FIS\Controllers\TeknisaCrud{

    protected $parameterBag;
    protected $crudService;
    protected $service;

    public function __construct($crudService, ParameterBag $parameterBag, Fis57000FichaConteudoImportacaoService $service) {
        $this->service = $service;
        parent::__construct($crudService, $parameterBag);
    }

    //Preenche o período do mapa selecionado
    public function apurarPeriodoFci(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $result = $this->service->apurarPeriodoFci($row);
            $response->addDataSet(new DataSet("result", $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    //Verifica se o período na criação ou edição de um mapa já engloba um período existente
    public function validaPeriodoMapa(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $result = $this->service->validaPeriodoMapa($row);
            $response->addDataSet(new DataSet("result", $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    //Salva os valores novamente após editar uma saída interestadual
    public function salvarValores(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $result = $this->service->salvarValores($row);
            $response->addDataSet(new DataSet("result", $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    //Salva o NRCTRLFCI(Número de controle) e passa o período para concluído
    public function salvarRecibo(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $result = $this->service->salvarRecibo($row);
            $response->addDataSet(new DataSet("result", $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    //Gera o arquivo Txt referente ao período selecionado
    public function geraTxtFci(DTO\Request $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            $linhasArq = $this->service->geraDadosFci($row);
            
            $acumulador = '';
            forEach($linhasArq as $linha){
                $acumulador .= $linha['DSLINHA']."\n";
            }
            
            $arrayFile["NMARQUIVO"] = "FCI_".$row['CDFILIALFCI'].$row['NRMAPAFCI'].".txt";
            $arrayFile["CONTEUDO"] = $acumulador;
            
            // Chama a função de criação do arquivo.
            $fileName = $this->createFileTxt($arrayFile);

            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function createFileTxt($row) {
        try {
            $file = fopen(sys_get_temp_dir() . DIRECTORY_SEPARATOR . $row["NMARQUIVO"], "w");
        } catch (\Exception $e) {
            throw new \Exception("Ocorreu um erro ao criar o arquivo para exportação.");
        }
            
        $text = $row['CONTEUDO'];
        $text = mb_convert_encoding($text, "UTF-8", "UTF-8"); 
        fprintf($file, "%s", $text);
        fclose($file);
        return $row["NMARQUIVO"];
    }
}
