<?php
namespace Teknisa\FIS\Modules\Acessorias\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Fis01800GiaSPFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    /*
     * Executa procedure para exportação da GIA - SP [ARQUIVO_GIA].
     */
    public function callExportacaoProcedure($params) {
        $procedure = new StoredProcedure($this->connection, 'ARQUIVO_GIA');

        $procedure->addParam(new Param('P_IDTRANSMITIDO', Param::PARAM_INPUT, $params["IDTRANSMITIDO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDINSCESTA', Param::PARAM_INPUT, $params["CDINSCESTA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDIMPOSTO', Param::PARAM_INPUT, $params["CDIMPOSTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TIPO', Param::PARAM_INPUT, $params["TIPO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_MOVIMENTO', Param::PARAM_INPUT, $params["MOVIMENTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDVERSAO', Param::PARAM_INPUT, $params["CDVERSAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQARQMAG', Param::PARAM_INPUT, $params["NRSEQARQMAG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDLIVROMAG', Param::PARAM_INPUT, $params["CDLIVROMAG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_GERADIPAM', Param::PARAM_INPUT, $params["GERADIPAM"], Param::PARAM_TYPE_STR));

        $procedure->execute();
    }

    /*
     * Função para excluir os dados gerados na procedure da GIA - SP.
     */
    public function deleteGiaData($params) {
        // Query a ser executada.
        $sql = "DELETE FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);
    }

    /*
     * Função para retornar os dados gerados na procedure da GIA - SP.
     */
    public function getGiaData($params) {
        // Query a ser executada.
        $sql = "SELECT T.NRSEQARQMAG, T.NRORDREGARQ, T.DSREGARQMAG , T.SQUENCIAL FROM( SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG , ROWNUM as SQUENCIAL FROM ( SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG ORDER BY NRORDREGARQ, SUBSTR(DSREGARQMAG,1,17))) T";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetchAll();
    }
    
    public function findAgendamento() {
        // Query a ser executada.
        $sql = "SELECT 
                    A.NRORG,
                    A.NRAGENDAMENTO,
                    A.CDTELA,
                    A.CDEMPRESA,
                    E.NMEMPRESA,
                    A.CDINSCESTA,
                    A.DTAGENDAMENTO,
                    A.DTINICIAL,
                    A.DTFINAL,
                    A.CDCAMPO1 AS CDLIVROMAG,
                    A.CDCAMPO2 AS TIPO,
                    A.CDCAMPO3 AS MOVIMENTO,
                    A.CDCAMPO4 AS CDVERSAO,
                    A.CDCAMPO5 AS IDTRANSMITIDO,
                    A.CDCAMPO6 AS GERADIPAM,
                    DECODE(A.IDPERIAGEN, '0', A.DTINICIAL,
                                           '1', TO_CHAR(SYSDATE, 'DD/MM/YYYY'),
                                           '2', TO_CHAR(ADD_MONTHS(SYSDATE,(-1)), 'DD/MM/YYYY')) AS DTREFINI,
                    L.NMLIVROMAG,
                    A.IDPERIAGEN,
                    A.IDSTATUS
                    FROM AGENDOBRIGACESS A,
                    EMPRESA E,
                    LIVROMAGNETICO L
                    WHERE CDTELA  = 'FIS01800'
                    AND A.CDEMPRESA = E.CDEMPRESA
                    AND A.CDCAMPO1 = L.CDLIVROMAG";

        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute();
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function insertAgendamento($row) {
        $sql = "INSERT INTO AGENDOBRIGACESS
            ( 
                NRORG,
                NRAGENDAMENTO,
                CDTELA,
            	CDEMPRESA,
                CDINSCESTA,
            	DTAGENDAMENTO,
            	DTINICIAL,
            	DTFINAL,
            	IDPERIAGEN,
            	
            	CDCAMPO1,
                CDCAMPO2,
                CDCAMPO3,
                CDCAMPO4,
                CDCAMPO5,
                CDCAMPO6,
                DTCAMPO1   ) 
             VALUES (
                :NRORG,
                :NRAGENDAMENTO,
                :CDTELA,
                :CDEMPRESA,
                :CDINSCESTA,
                :DTAGENDAMENTO,
                :DTINICIAL,
                :DTFINAL,
                :IDPERIAGEN,
                :CDCAMPO1,
                :CDCAMPO2,
                :CDCAMPO3,
                :CDCAMPO4,
                :CDCAMPO5,
                :CDCAMPO6,
                :DTCAMPO1 )";
                
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            "IDPERIAGEN"=> $row["IDPERIAGEN"],
            "CDCAMPO1"  => $row["CDLIVROMAG"],
            "CDCAMPO2"  => $row["TIPO"],
            "CDCAMPO3"  => $row["MOVIMENTO"],
            "CDCAMPO4"  => $row["CDVERSAO"],
            "CDCAMPO5"  => $row["IDTRANSMITIDO"],
            "CDCAMPO6"  => $row["GERADIPAM"],
            "DTCAMPO1"  => $row["DTREFINI"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateAgendamento($row) {
        $sql = "UPDATE AGENDOBRIGACESS
                    SET CDEMPRESA = :CDEMPRESA,
                        CDINSCESTA = :CDINSCESTA,
                    	DTAGENDAMENTO = :DTAGENDAMENTO,
                    	DTINICIAL = :DTINICIAL,
                    	DTFINAL = :DTFINAL,
                    	IDPERIAGEN = :IDPERIAGEN,
                    	CDCAMPO1 = :CDCAMPO1,
                        CDCAMPO2 = :CDCAMPO2,
                        CDCAMPO3 = :CDCAMPO3,
                        CDCAMPO4 = :CDCAMPO4,
                        CDCAMPO5 = :CDCAMPO5,
                        CDCAMPO6 = :CDCAMPO6,
                        DTCAMPO1 = :DTCAMPO1
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND CDTELA = :CDTELA";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            "IDPERIAGEN"=> $row["IDPERIAGEN"],
            "CDCAMPO1"  => $row["CDLIVROMAG"],
            "CDCAMPO2"  => $row["TIPO"],
            "CDCAMPO3"  => $row["MOVIMENTO"],
            "CDCAMPO4"  => $row["CDVERSAO"],
            "CDCAMPO5"  => $row["IDTRANSMITIDO"],
            "CDCAMPO6"  => $row["GERADIPAM"],
            "DTCAMPO1"  => $row["DTREFINI"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateAgendamentoIdStatus($row, $idstatus) {
        $sql = "UPDATE AGENDOBRIGACESS
                    SET IDSTATUS = :IDSTATUS
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND CDTELA = :CDTELA";
                    
        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"],
            "CDTELA"=>$row["CDTELA"],
            "IDSTATUS"=>$idstatus
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getInscEsta($row) {
        // Query a ser executada.
        $sql = "SELECT CDINSCESTA FROM INSCRESTAD WHERE CDEMPRESA = :CDEMPRESA";

        $params = array(
            'CDEMPRESA' => $row['CDEMPRESA']
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function getAgendamentoInsert($row) {
        // Query a ser executada.
        $sql = "SELECT * FROM AGENDOBRIGACESS 
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";

        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function getConfiguraSMTP($row)  {
        // Query a ser executada.
        $sql = "SELECT * FROM CONFIGURASMTP
                    WHERE NRORG = :NRORG";
        
        $params = array(
            "NRORG"=> $row["NRORG"]
        );
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getContatos($row)  {
        // Query a ser executada.
        $sql = "SELECT * FROM CONTATOAPURAC
                    WHERE NRORG = :NRORG
                    AND CDEMPRESA = :CDEMPRESA
                    AND IDEXPORTAUTO = 'S'";
        
        $params = array(
            "NRORG"=> $row["NRORG"],
            "CDEMPRESA"=> $row["CDEMPRESA"]
        );
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getAgendamentoArquivo($row) {
        $sql = "SELECT * FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function deleteAgendamentoArquivo($row) {
        $sql = "DELETE FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"]
        );
        var_dump($params);
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
    }
  
    public function deleteAgendamento($row) {
        // Query a ser executada.
        $sql = "DELETE FROM AGENDOBRIGACESS 
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";

        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
    }
    
    public function findAgendamentoExec($row) {
        // Query a ser executada.
        $sql = "SELECT 
                    TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI') AS DTATUAL,
                    TO_CHAR(ADD_MONTHS(SYSDATE,(-1)), 'DD/MM/YYYY HH24:MI') AS LAST_MONTH,
                    A.NRAGENDAMENTO,
                    A.CDTELA,
                    A.CDEMPRESA,
                    A.CDINSCESTA,
                    A.DTAGENDAMENTO,
                    A.DTINICIAL,
                    A.DTFINAL,
                    A.CDCAMPO1 AS CDLIVROMAG,
                    L.NMLIVROMAG,
                    A.CDCAMPO2 AS TIPO,
                    A.CDCAMPO3 AS MOVIMENTO,
                    A.CDCAMPO4 AS CDVERSAO,
                    A.CDCAMPO5 AS IDTRANSMITIDO,
                    A.CDCAMPO6 AS GERADIPAM,
                    A.DTCAMPO1 AS DTREFINI,
                    A.IDPERIAGEN,
                    A.IDSTATUS
                    FROM AGENDOBRIGACESS A,
                    LIVROMAGNETICO L
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND A.CDCAMPO1 = L.CDLIVROMAG";
        
        $params = array(
            "NRAGENDAMENTO"=> $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getNmEmpresa($row) {
        // Query a ser executada.
        $sql = "SELECT NMEMPRESA FROM EMPRESA
                    WHERE CDEMPRESA = :CDEMPRESA
                    AND NRORG = :NRORG";
        
        $params = array(
            "CDEMPRESA"=> $row["CDEMPRESA"],
            "NRORG"=> $row["NRORG"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetch();
    }
    
    public function verAgendamentoArquivo($row) {
        $sql = "SELECT * FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                AND NMARQUIVO = :NMARQUIVO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "NMARQUIVO" => $row["NMARQUIVO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function insertAgendamentoArquivo($row) {
        $sql = "INSERT INTO ARQUIOBRIGACESS
            ( 
                NRORG,
                NRARQUIVO,
                NRAGENDAMENTO,
                CDTELA,
                CDEMPRESA,
                CDINSCESTA,
                DTAGENDAMENTO,
                DTEXECAGEND,
                NMARQUIVO,
                NMPATHARQ
            )
             VALUES (
                :NRORG,
                :NRARQUIVO,
                :NRAGENDAMENTO,
                :CDTELA,
                :CDEMPRESA,
                :CDINSCESTA,
                :DTAGENDAMENTO,
                :DTEXECAGEND,
                :NMARQUIVO,
                :NMPATHARQ  )";
        
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRARQUIVO"     => $row["NRARQUIVO"],
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            "DTEXECAGEND"   => $row["DTEXECAGEND"],
            "NMARQUIVO"     => $row["NMARQUIVO"],
            "NMPATHARQ"     => $row["NMPATHARQ"]
            
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
       
}
