<?php
namespace Teknisa\FIS\Services;

use Doctrine\ORM\EntityManager;

class Ger99100RelacionamentoImpostosFiscaisService {

    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function removeNfeRelationship($row) {
        $impostosRemaining = $this->entityManager->getRepository('Teknisa\Model\Fiscal\Entities\Imposto')->findOneBy(
                array('nrorg' => $row['NRORG'], 'cdimpostonfe' => $row['CDIMPOSTONFE']));
                
            
        $mapaapurac = $this->entityManager->getRepository('Teknisa\Model\Fiscal\Entities\Mapaapurac')->findOneBy(
                array('cdimposto' => $row['CDIMPOSTONFE']));
                
        if($mapaapurac === null) {
            $imposto = $this->entityManager->getRepository('Teknisa\Model\Fiscal\Entities\Imposto')->findOneBy(
                array('nrorg' => $row['NRORG'], 'cdimposto' => $row['CDIMPOSTO']));
                
            $imposto->setCdimpostonfe(null);
            $this->entityManager->persist($imposto);
            // Verifica se há algum imposto ainda relacionado ao ImpostoNFE além do que foi removido, ou seja, se havia mais de um imposto relacionado. Se não houver, retira a parametrização deste.
            $pkCount = (is_array($impostosRemaining) ? count($impostosRemaining) : 1);
            if ($pkCount == 1) {
                $impostonfe = $this->entityManager->getRepository('Teknisa\Model\Fiscal\Entities\Impostonfe')->findOneBy(
                    array('nrorg' => $row['NRORG'], 'cdimpostonfe' => $row['CDIMPOSTONFE']));
                
                $impostonfe->setIdimporecupnfe(null);
                $impostonfe->setIdorgarrecadnfe(null);
                $impostonfe->setIdformapurnfe(null);
                $this->entityManager->persist($impostonfe);
            }
            $this->entityManager->flush();
        } else {
            throw new \Exception("Exclusão não permitida. Existe mapa de apuração para esse imposto.");
        }
    }

    private function removePreviousXmlRelationship($row) {
        $imposto = $this->entityManager->getRepository('Teknisa\Model\Fiscal\Entities\Imposto')->findOneBy(
                array('nrorg' => $row['NRORG'], 'cdimpostoxml' => $row['CDIMPOSTONFE']));
                
        if (!is_null($imposto)) {
            $imposto->setCdimpostoxml(null);
            $this->entityManager->persist($imposto);
            $this->entityManager->flush();
        }
    }

    public function saveNfeRelationship($row) {
        $imposto = $this->entityManager->getRepository('Teknisa\Model\Fiscal\Entities\Imposto')->findOneBy(
                array('nrorg' => $row['NRORG'], 'cdimposto' => $row['CDIMPOSTO']));
                
        if (!is_null($imposto->getCdimpostonfe())) {
            throw new \Exception("Imposto já relacionado.");
        }
        
        $impostonfe = $this->entityManager->getRepository('Teknisa\Model\Fiscal\Entities\Impostonfe')->findOneBy(
                array('nrorg' => $row['NRORG'], 'cdimpostonfe' => $row['CDIMPOSTONFE']));
        // Se existe parametrização do ImpostoNFE, verifica se o imposto inserido possui a mesma parametrização
        if (!empty($impostonfe->getIdimporecupnfe())) {
            if ($impostonfe->getIdimporecupnfe() != $imposto->getIdimporecup()) {
                throw new \Exception("Tratamento de Imposto Recuperável do Imposto Fiscal difere do imposto informado.");
            }
            if ($impostonfe->getIdorgarrecadnfe() != $imposto->getIdorgarrecad()) {
                throw new \Exception("Orgão Arrecadador do Imposto Fiscal difere do imposto informado.");
            }
            if ($impostonfe->getIdformapurnfe() != $imposto->getIdformapur()) {
                throw new \Exception("Forma de Apuração do Imposto Fiscal difere do imposto informado.");
            }
        }
        // Se não existe, determina a parametrização de acordo com o imposto inserido
        else {
            $impostonfe->setIdimporecupnfe($imposto->getIdimporecup());
            $impostonfe->setIdorgarrecadnfe($imposto->getIdorgarrecad());
            $impostonfe->setIdformapurnfe($imposto->getIdformapur());
            $this->entityManager->persist($impostonfe);
        }
       
        $imposto->setCdimpostonfe($row['CDIMPOSTONFE']);
        $this->entityManager->persist($imposto);
        $this->entityManager->flush();
    }

    public function saveXmlRelationship($row) {
        if (!empty($row['CDIMPOSTO'])) {
            
            $imposto = $this->entityManager->getRepository('Teknisa\Model\Fiscal\Entities\Imposto')->findOneBy(
                array('nrorg' => $row['NRORG'], 'cdimposto' => $row['CDIMPOSTO']));
            
            if ($imposto->getCdimpostoxml() != $row['CDIMPOSTONFE']) {
                if (!is_null($imposto->getCdimpostoxml())) {
                    throw new \Exception("Imposto já relacionado.");
                }
                $this->removePreviousXmlRelationship($row);
                $imposto->setCdimpostoxml($row['CDIMPOSTONFE']);
            }
            $imposto->setIdimportaimpxml($row['IDIMPORTAIMPXML']);
            $imposto->setCdencargoimpxml($row['CDENCARGOIMPXML']);
            $this->entityManager->persist($imposto);
            $this->entityManager->flush();
        }
        else {
            $this->removePreviousXmlRelationship($row);
        }
    }
    
      
    
        const GET_IMPOSTO = "SELECT CDIMPOSTONFE, SGIMPOSTONFE, IDIMPORECUPNFE, IDORGARRECADNFE, IDFORMAPURNFE FROM IMPOSTONFE WHERE CDIMPOSTONFE = :P_CDIMPOSTONFE";
                            
        const INSERT_IMPOSTO = "Insert into IMPOSTONFE (CDIMPOSTONFE,SGIMPOSTONFE,IDIMPORECUPNFE,IDORGARRECADNFE,IDFORMAPURNFE) values (:P_CDIMPOSTONFE, :P_SGIMPOSTONFE, null, null, null)";
        
        const UPDATE_IMPOSTO = "UPDATE IMPOSTONFE SET SGIMPOSTONFE =:P_SGIMPOSTONFE WHERE CDIMPOSTONFE =:P_CDIMPOSTONFE";
                            
        public function incluirImpostos () {
            $array = array( '00' => 'ICMS',
                            '01' => 'FECP',
                            '03' => 'CARGA RJ',
                            '05' => 'ICMS-COMPL',
                            '06' => 'ST-COMPL',
                            '10' => 'IPI',
                            '20' => 'II',
                            '21' => 'IRRF-E',
                            '22' => 'IRRF-S',
                            '24' => 'PCC',
                            '25' => 'IRPJ',
                            '26' => 'FUNRURAL',
                            '30' => 'ISSQN-E',
                            '31' => 'ISSQN-S',
                            '35' => 'ISS-RET-E',
                            '36' => 'ISS-RET-S',
                            '40' => 'IOF',
                            '41' => 'INSS-RET-E',
                            '42' => 'INSS-RET-S',
                            '50' => 'PIS',
                            '51' => 'PIS GER',
                            '55' => 'PIS-RET-E',
                            '56' => 'PIS-RET-S',
                            '60' => 'COFINS',
                            '61' => 'PIS GER',
                            '65' => 'COF-RET-E',
                            '66' => 'COF-RET-S',
                            '70' => 'CSLL',
                            '75' => 'CSLL-RET-E',
                            '76' => 'CSLL-RET-S',
                            '80' => 'ICMS ST',
                            '85' => 'PIS ST',
                            '90' => 'COFINS ST'
                            );
            foreach( $array as $cdimpostonfe => $sgimpostonfe ) {
                $result = $this->entityManager->getConnection()->fetchAll(self::GET_IMPOSTO, array( 'P_CDIMPOSTONFE' => $cdimpostonfe) );
                 
                 if (count($result) == 0){
                     $params = array('P_CDIMPOSTONFE' => $cdimpostonfe,
                                     'P_SGIMPOSTONFE' => $sgimpostonfe);
                     $std = $this->connection->prepare(self::INSERT_IMPOSTO);
                     $std->execute($params);
                     
                 } else if ($sgimpostonfe != $result[0]["SGIMPOSTONFE"]){
                     $params = array('P_CDIMPOSTONFE' => $cdimpostonfe,
                                     'P_SGIMPOSTONFE' => $sgimpostonfe);
                     $std = $this->connection->prepare(self::UPDATE_IMPOSTO);
                     $std->execute($params);
                 }
            }
        }

}

